% EasySpin toolbox
%  
% General 
%   easyspininfo  - Information about EasySpin installation 
%   eprload       - Read spectrum files in common EPR data formats 
%  
% Spectral simulations 
%   chili         - Slow-motion cw EPR spectra 
%   garlic        - Isotropic and fast-motion cw EPR spectra 
%   pepper        - Solid-state cw EPR spectra 
%   salt          - ENDOR spectra 
%   nucfrq2d      - Sketch of HYSCORE spectra 
%   
% Utilities 
%   eprconvert    - Graphical frequency/field/g value conversion utility 
%   fastmotion    - Fast-motion regime line width parameters from rotational correlation time 
%   isotopes      - A browsable list of isotopes 
%   mhz2mt        - Unit conversion from MHz to mT 
%   mt2mhz        - Unit conversion from mT to MHz   
%  
% Spin systems 
%   nucspinadd    - Adds a nuclear spin to a spin system 
%   nucspinrmv    - Removes a nuclear spin from a spin system 
%   
% Data analysis 
%   basecorr      - Polynomial baseline correction 
%   ctafft        - Cross-term averaged FFT 
%   deriv         - Numerical differentiation 
%   exponfit      - Exponential fitting 
%   fdaxis        - Frequency domain axis for FFT 
%   pseumod       - Pseudo-modulation of EPR absorption spectra 
%   rcfilt        - RC filtering of EPR spectra 
%   smooth        - Moving averages: smoothing and differentiation 
%   
% Vectors, orientations and angles 
%   ang2vec       - Converts polar angles to cartesian unit vector 
%   erot          - Computes rotation matrix from Euler angles 
%   eulang        - Euler angles from rotation matrix 
%   rotaxi2mat    - Convert rotation axis plus angle to rotation matrix
%   rotmat2axi    - Convert rotation matrix to axis plus angle
%   vec2ang       - Polar angles from cartesian unit vector 
%   
% Line shapes and windows 
%   apowin        - Apodization windows. 
%   convspec      - Convolute spectrum with line shape 
%   gaussian      - Gaussian line shape 
%   lorentzian    - Lorentzian line shape   
%   lshape        - General line shape function 
%   makespec      - Construct spectrum from peak positions and amplitudes 
%   voigtian      - Voigtian line shape function 
%   
% Physical constants 
%   nucabund      - Natural abundance of nuclear isotopes 
%   nucdata       - Nuclear spin data 
%   nucgval       - Nuclear g values 
%   nucqmom       - Nuclear electric quadrupole moments 
%   nucspin       - Nuclear spin quantum numbers 
%     
%   amu           - Atomic unit of mass 
%   avogadro      - Avogadro constant 
%   barn          - Conventional unit of nuclear quadupole moments 
%   bmagn         - Bohr magneton 
%   bohrrad       - Bohr radius 
%   boltzm        - Boltzmann constant 
%   clight        - Vacuum speed of light 
%   echarge       - Elementary electric charge 
%   emass         - Mass of electron 
%   faraday       - Faraday constant 
%   gfree         - g value of the free electron 
%   hartree       - Atomic unit of energy 
%   molgas        - Molar gas constant 
%   nmagn         - Nuclear magneton 
%   nmass         - Mass of neutron 
%   planck        - Planck constant 
%   pmass         - Mass of proton 
%   rydberg       - Rydberg constant 
%   
% Basic spin physics 
%   commute       - Commutator of two matrices 
%   equivcouple   - Coupling of equivalent spins 
%   equivsplit    - Splitting pattern for equivalent spins 
%   hsdim         - State space dimension of a spin system 
%   larmorfrq     - Larmor frequency of nuclear spins 
%   sop           - Spin operator matrices 
%   spinvec       - Spin quantum numbers in a spin system 
%   stev          - Extended Stevens operator matrices 
%
% Angular momentum
%   clebschgordan - Clebsch-Gordan coefficients 
%   plegendre     - Associated Legendre polynomials
%   spherharm     - Spherical harmonics
%   wigner3j      - Wigner 3-j symbols 
%   wigner6j      - Wigner 6-j symbols 
%   
% Energy levels, resonances and propagations 
%   eigfields     - Resonance fields using eigenfield equation 
%   endorfrq      - ENDOR frequencies and amplitudes 
%   evolve        - Evolves density matrices in time-domain 
%   levels        - Energy levels computation 
%   levelsplot    - Energy levels and resonances plot 
%   orisel        - Orientation selection 
%   propint       - Compute pulse propagator 
%   resfields     - General resonance fields and amplitudes 
%   
% Hamiltonians and densities 
%   eeint         - Electron-electron interaction Hamiltonian 
%   hfine         - Hyperfine interaction Hamiltonian 
%   internal      - Internal interactions Hamiltonian 
%   nquad         - Nuclear quadrupole interaction Hamiltonian 
%   sham          - Full Spin Hamiltonian 
%   sigeq         - Thermal equilibrium density matrix 
%   symm          - Symmetry determination for Spin Hamiltonians 
%   zeeman        - Zeeman Hamiltonian 
%   zfield        - Electronic zero field interaction Hamiltonian 
%   
% Orientations 
%   sphgrid       - Triangular orientational grids 
%   sphrand       - Random orientational grids 
%   sphtri        - Triangulation of orientational grids % Optimization Toolbox
-1.000000e+00
