% pepper  Computation of powder cw EPR spectra 
%
%   pepper(Sys,Exp)
%   pepper(Sys,Exp,Opt)
%   spec = pepper(...)
%   [B,spec] = pepper(...)
%   [B,spec,Trans] = pepper(...)
%
%   Calculates a field-swept cw EPR spectrum.
%
%   Input:
%   - Sys: spin system structure specification
%       S, g, Nucs, A, Q, D, ee,
%       gpa, Apa, Qpa, Dpa, eepa
%       HStrain, gStrain, AStrain, DStrain, lw
%       B20 etc.
%   - Exp: experiment specification
%       mwFreq        spectrometer frequency, in GHz
%       CenterSweep   magnetic field range [center,sweep], in mT
%       Range         magnetic field range [low,high], in mT
%       nPoints       number of points
%       Temperature   temperature of the sample, by default off
%       Harmonic      detection harmonic: 0, 1 (default), 2
%       Detection     detection mode: 'parallel', 'perpendicular' (default)
%       Orientations  orientations for single-crystal simulations
%       Nematic       FWHM of nematic orientational distribution
%   - Opt: computations options
%       Symmetry, SymmFrame, LineShape, Output,
%       nKnots, nSpline, Intensity
%       Transitions, nTransitions, Threshold
%
%   Output:
%   - B: the field axis [mT]
%   - spec: the spectrum
%   - Trans: transitions included in the calculation
%   If no output argument is given, the simulated spectrum is plotted.

