% ENDOR excitation widths and orientation selectivity
%=======================================================================
clear all, close all

% Axial S=1/2 system with 1 proton.
Sys = struct('S',1/2,'g',[2 2 2.2],'Nucs','1H','A',[-1 -1 2]*2+3);
Sys.lwEndor = 0.1;

% X band conditions.
Exp = struct('mwFreq',9.5,'Field',315,'Range',[8 18],'nPoints',1000);
Opt = struct('nKnots',91);

% Now we loop over a set of different excitation widths
% to demonstrate the effect on the ENDOR spectra.
Ex = [1e5 1000 500 200 100 50 10];

for k = 1:numel(Ex)
  fprintf('Excitation FWHM %g MHz\n',Ex(k));
  Exp.ExciteWidth = Ex(k);
  [x,y(k,:)] = salt(Sys,Exp,Opt);
end

plot(x,y); axis tight
xlabel('ENDOR frequency [MHz]');
ylabel('Intensity [a.u.]');
