% Speed-up of ENDOR simulations using orientation pre-selection
%======================================================================
% Opt.OriPreSelect provides a speed-up for simulations of
% strongly orientation-selective ENDOR spectra. If the orientation
% selection is not strong, the speed-up is only minor.

clear all, close all

% Definition of the spin system
Sys = struct('S',1/2,'g',[2.3,2.1,2]);
Sys = nucspinadd(Sys,'1H',[3,6,2]);
Sys = nucspinadd(Sys,'1H',[5,3,1]);
Sys = nucspinadd(Sys,'1H',[8,6,-4]);
Sys.HStrain = [1 1 1]*100;     % MHz
Sys.lwEndor = 0.1;    % MHz

% ENDOR simulations
EndorExp = struct('mwFreq',9.5,'Field',295,'ExciteWidth',50);
B0 = 295; % mT
EndorExp.Field = B0;
EndorExp.Range = larmorfrq('1H',B0) + [-1 1]*10; % MHz

Opt = struct('nKnots',51);

% (1) no orientation pre-selection: slow
Opt.OriPreSelect = 0;
[x,y1] = salt(Sys,EndorExp,Opt);

% (2) with orientation pre-selection: faster
Opt.OriPreSelect = 1;
[x,y2] = salt(Sys,EndorExp,Opt);

plot(x,y1,'g',x,y2,'r')

xlabel('frequency [MHz]');
title('ENDOR spectra');
