% Fremy's salt (PADS), motional narrowing
%--------------------------------------------------
% Values taken from Goldman et al, J.Chem.Phys 56(2), 716 (1972)

clear all, close all

% PADS in 85% glycerol/15% H2O
Sys.g = [2.00785, 2.00590, 2.00265];
Sys.Nucs = '14N';
Sys.A = mt2mhz([5.5 5.0 28.7]/10); % G -> MHz

% Rotational motion at 30 degree Celsius
Sys.tcorr = 8e-10; % seconds
Sys.lw = 0.03; % mT

% X band experimental conditions
Exp = struct('mwFreq',9.5,'nPoints',1e4,'CenterSweep',[338.5 5]);

% Simulation
[x,y] = garlic(Sys,Exp);

% Graphical rendering
plot(x,y);
xlabel('magnetic field [mT]');
axis tight
set(gca,'TickDir','out');

% Removing the box and the y axis
set(gca,'YTick',[],'YColor','w');
box off
