% Phenalenyl radical anion, including 13C satellite lines
%==========================================================================
% Hyperfine values taken from Gerson book, Table 8.4, page 225

clear all, close all

% Parameters
%--------------------------------------------------------------------------
A_H = mt2mhz([-0.629 +0.181]);
A_C = mt2mhz([+0.966 -0.784 -0.784]);
Sys = struct('g',2,'Nucs','1H,1H','n',[6 3]);
Sys.A = A_H;
Sys.lw = 0.01;

Exp = struct('mwFreq',9.5,'nPoints',8192,'Range',[336.5 342.5]);

% Simulations
%--------------------------------------------------------------------------

% Spectrum of all-12C species
[x,y0] = garlic(Sys,Exp);


% Spectra with species containing 1 13C
Sys.Nucs = '1H,1H,13C';
Sys.n = [6 3 1];
% 13C in one of positions 1,3,4,6,7,9
Sys.A = [A_H A_C(1)];
[x,y1] = garlic(Sys,Exp);
% 13C in one of positions 2,5,8
Sys.A = [A_H A_C(2)];
[x,y2] = garlic(Sys,Exp);
% 13C in one of positions 3a,6a,9a
Sys.A = [A_H A_C(3)];
[x,y3] = garlic(Sys,Exp);

abund = nucabund('12C,13C');
aC12 = abund(1)^12;
aC13 = abund(1)^11*abund(2)^1;
y_total = aC12*y0 + aC13*(6*y1 + 3*y2 + 3*y3);

% Species with more than one 13C are neglected...


% Graphical rendering
%--------------------------------------------------------------------------
plot(x,y_total);
xlabel('magnetic field [mT]');
set(gca,'YTick',[]);
axis tight

