% [Cu(mnt)2] at 1.4 GHz, single-crystal
%==========================================================================
% Values from Kirmse et al., Inorg.Chem. 23, 3333-3338 (1984)
clear all, close all

% spin system with 63Cu
Sys63 = struct('Nucs','63Cu','lw',.4);
Sys63.g = [2.020 2.023 2.089];
A = [-43.1 -43.7 -171.4]*1e-4; % cm^-1
Sys63.A = A*100*clight/1e6; % conversion cm^-1 -> MHz

% spin system with 65Cu
Sys65 = Sys63;
Sys65.Nucs = '65Cu';
Sys65.A = Sys63.A*nucgval('65Cu')/nucgval('63Cu');

% experimental parameters
Exp = struct('mwFreq',1.4,'Range',[10 90]);

% options
Opt.Verbosity = 1;

% simulation of two single-crystal spectra
% in one pepper call
Exp.Orientations = [0 0; pi/2 0];
Opt.Output = 'separate';
[B,spec63] = pepper(Sys63,Exp,Opt);
[B,spec65] = pepper(Sys65,Exp,Opt);
w63 = 0.692;
spec = w63*spec63 + (1-w63)*spec65;
spec1 = spec(1,:);
spec2 = spec(2,:);

% display
plot(B,spec1,'r',B,spec2-max(spec1),'b'); axis tight
set(gca,'YTick',[]);
legend('90^o','0^o');
xlabel('magnetic field [mT]');
title(sprintf('%g GHz single-crystal spectra of Cu(mnt)2',Exp.mwFreq));

%end