% effect of g strain at various mw frequencies
%==========================================================================
clear all, close all

% Spin system, experiment parameters and options
%------------------------------------------------------------
gStrain = [0.001 0.0008 0.0005];
Sys = struct('S',.5,'g',[2.0104 2.0074 2.0026],...
       'Nucs','14N','A',[18 19 92],...
       'gStrain',gStrain);
Par.Harmonic = 0;
Opt = [];

% Frequencies [GHz] and associated magnetic field ranges [mT]
%------------------------------------------------------------
Freqs = [3 9.5 35 95 350];
Ranges = {[102 112],[334 344],[1240 1255],[3372 3395],[12425 12505]};

% Simulating all spectra with and without g strain
%------------------------------------------------------------
for k=1:length(Freqs)
  fprintf('%g GHz\n',Freqs(k));
  
  Par.mwFreq = Freqs(k);
  Par.Range = Ranges{k};
  
  Sys.gStrain = [0 0 0];
  [x{k},y1{k}] = pepper(Sys,Par,Opt);
  
  Sys.gStrain = gStrain;
  [x{k},y2{k}] = pepper(Sys,Par,Opt);
end

% Graphical rendering of the results
%------------------------------------------------------------
for k = 1:length(Freqs)
  subplot(length(Freqs),1,k);
  h = plot(x{k},y1{k}/max(y1{k}(:))+(k-1)*1.2,'r',...
     x{k},y2{k}/max(y2{k}(:))+(k-1)*1.2,'k');
  set(h(2),'LineWidth',2);
  axis tight
  xx = xlim; yy = ylim;
  text(xx(1),mean(yy),sprintf('%g GHz',Freqs(k)),'FontSize',12,'FontWeight','bold');
  set(gca,'YTick',[],'YColor','w','Box','off','TickDir','out');
end
xlabel('magnetic field [mT]');

% end
