% Effect of modulation amplitude on the line shape in cw EPR
%==========================================================================
clear all, close all

% Define a single-line absorption spectrum
x = linspace(-10,10,1e3);
FWHM = 1; % line width (full width at half height)
Spc = lorentzian(x,0,FWHM);

% Compute the 1st-harmonic signal detected with field modulation
ModAmpl = [0.05 0.1 0.2 0.5 1 2 5]*FWHM;
for m = 1:numel(ModAmpl)
  y = pseumod(x,Spc,ModAmpl(m),1); % 1st harmonic
  ModSpc(m,:) = y/max(y); % normalized 1st harmonic
  y = cumtrapz(y); % integral of 1st harmonic
  ModSpcInt(m,:) = y/max(y); % normalized integral
end

% Plot results
subplot(3,1,1)
plot(x,Spc);
title('Original absorption signal');
axis tight

subplot(3,1,2);
plot(x,ModSpc);
title('1st harmonic signal with various modulation amplitudes');
axis tight

subplot(3,1,3);
plot(x,ModSpcInt);
title('Integrals of 1st harmonic signal');
axis tight

% Conclusion: A Lorentzian lnie shape is distorted in
% standard cw EPR measurement of the first harmonic,
% if the the peak-to-peak modulation amplitude exceeds
% 20% of the FWHM of the absorption line.
